==> gottet-1.0.6-src.tar.bz2: gottet-1.0.6/translations/gottet_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>Board</name>
    <message>
        <location filename="../src/board.cpp" line="89"/>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="89"/>
        <source>End the current game?</source>
        <translation>Voleu finalitzar la partida actual?</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="175"/>
        <source>&lt;big&gt;&lt;b&gt;Paused&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to resume playing.</source>
        <translation>&lt;big&gt;&lt;b&gt;En pausa&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Feu clic per continuar la partida..</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="403"/>
        <source>&lt;big&gt;&lt;b&gt;Game Over!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to start a new game.</source>
        <translation>&lt;big&gt;&lt;b&gt;Partida finalitzada&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Feu clic per començar una partida nova.</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../src/locale_dialog.cpp" line="50"/>
        <source>Select application language:</source>
        <translation>Seleccioneu l’idioma de l’aplicació:</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="53"/>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Idioma del sistema&gt;</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="183"/>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="183"/>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Reinicieu l‘aplicació perquè el canvi d’idioma tingui efecte.</translation>
    </message>
</context>
<context>
    <name>ScoreBoard</name>
    <message>
        <location filename="../src/score_board.cpp" line="33"/>
        <source>Gottet Scores</source>
        <translation>Puntuacions del Gottet</translation>
    </message>
    <message>
        <location filename="../src/score_board.cpp" line="37"/>
        <source>Level</source>
        <translation>Nivell</translation>
    </message>
    <message>
        <location filename="../src/score_board.cpp" line="37"/>
        <source>Lines</source>
        <translation>Línies</translation>
    </message>
    <message>
        <location filename="../src/score_board.cpp" line="37"/>
        <source>Score</source>
        <translation>Puntuació</translation>
    </message>
    <message>
        <location filename="../src/score_board.cpp" line="56"/>
        <source>OK</source>
        <translation>D’acord</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/window.cpp" line="44"/>
        <location filename="../src/window.cpp" line="221"/>
        <source>Gottet</source>
        <translation>Gottet</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="93"/>
        <source>Click to start a new game.</source>
        <translation>Feu clic per començar una partida nova.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="111"/>
        <source>&amp;Game</source>
        <translation>&amp;Partida</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="112"/>
        <source>&amp;New</source>
        <translation>&amp;Nova</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="112"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="113"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pausa</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="113"/>
        <location filename="../src/window.cpp" line="115"/>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="115"/>
        <source>&amp;Resume</source>
        <translation>&amp;Reprèn</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="118"/>
        <source>&amp;Scores</source>
        <translation>P&amp;untuacions</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="120"/>
        <source>&amp;Quit</source>
        <translation>&amp;Surt</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="120"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="122"/>
        <source>&amp;Settings</source>
        <translation>&amp;Configuració</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="123"/>
        <source>Application &amp;Language...</source>
        <translation>Idioma de l’aplicació…</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="125"/>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="126"/>
        <source>&amp;About</source>
        <translation>&amp;Quant a</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="127"/>
        <source>About &amp;Qt</source>
        <translation>Q&amp;uant al Qt</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="141"/>
        <source>Next Piece</source>
        <translation>Peça següent</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="143"/>
        <source>Level</source>
        <translation>Nivell</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="145"/>
        <source>Removed Lines</source>
        <translation>Línies eliminades</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="147"/>
        <source>Score</source>
        <translation>Puntuació</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="220"/>
        <source>About</source>
        <translation>Quant a</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="222"/>
        <source>A tetris clone I made for my wife</source>
        <translation>Un clon del Tetris que vaig crear per a la meva esposa</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="223"/>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott.</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="224"/>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Publicat sota la llicència &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
</context>
</TS>

==> gottet-1.2.0-src.tar.bz2: gottet-1.2.0/translations/gottet_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>Board</name>
    <message>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>Voleu finalitzar la partida actual?</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Paused&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to resume playing.</source>
        <translation>&lt;big&gt;&lt;b&gt;En pausa&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Feu clic per continuar la partida..</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Game Over!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to start a new game.</source>
        <translation>&lt;big&gt;&lt;b&gt;Partida finalitzada&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Feu clic per començar una partida nova.</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Seleccioneu l’idioma de l’aplicació:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Idioma del sistema&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Reinicieu l‘aplicació perquè el canvi d’idioma tingui efecte.</translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>Level</source>
        <translation>Nivell</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>Línies</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Puntuació</translation>
    </message>
    <message>
        <source>High Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>#%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Gottet</source>
        <translation>Gottet</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>Feu clic per començar una partida nova.</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Partida</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nova</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pausa</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>P&amp;untuacions</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Surt</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Configuració</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Idioma de l’aplicació…</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Quant a</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Q&amp;uant al Qt</translation>
    </message>
    <message>
        <source>Next Piece</source>
        <translation>Peça següent</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Nivell</translation>
    </message>
    <message>
        <source>Removed Lines</source>
        <translation>Línies eliminades</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Puntuació</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Quant a</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott.</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Publicat sota la llicència &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A simple falling blocks game</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
